@@ -2,4 +2,4 @@ from django.apps import AppConfig
 
 
 class JutilConfig(AppConfig):
-    name = 'jutil'
+    name = "jutil"
