@@ -4,7 +4,6 @@ from typing import Optional, Union, Tuple, Sequence, List
 from django.conf import settings
 from django.core.exceptions import ValidationError
 from django.core.mail import EmailMultiAlternatives
-from django.utils.timezone import now
 from django.utils.translation import gettext as _
 from base64 import b64encode
 from os.path import basename
@@ -113,11 +112,10 @@ def send_email_sendgrid(  # noqa
     except Exception as err:
         raise Exception("Using send_email_sendgrid() requires sendgrid pip install sendgrid>=6.3.1,<7.0.0") from err
 
+    if not api_key and hasattr(settings, "EMAIL_SENDGRID_API_KEY"):
+        api_key = settings.EMAIL_SENDGRID_API_KEY
     if not api_key:
-        if hasattr(settings, "EMAIL_SENDGRID_API_KEY"):
-            api_key = settings.EMAIL_SENDGRID_API_KEY
-        if not api_key:
-            raise Exception("EMAIL_SENDGRID_API_KEY not defined in Django settings and API key not passed in to send_email_sendgrid() either")
+        raise Exception("EMAIL_SENDGRID_API_KEY not defined in Django settings and API key not passed in to send_email_sendgrid() either")
 
     if files is None:
         files = []
@@ -127,7 +125,7 @@ def send_email_sendgrid(  # noqa
     bcc_recipients_clean = make_email_recipient_list(bcc_recipients)
 
     try:
-        sg = sendgrid.SendGridAPIClient(api_key=settings.EMAIL_SENDGRID_API_KEY)
+        sg = sendgrid.SendGridAPIClient(api_key=api_key)
         text_content = Content("text/plain", text) if text else None
         html_content = Content("text/html", html) if html else None
 
@@ -160,19 +158,15 @@ def send_email_sendgrid(  # noqa
                 attachment.disposition = Disposition("attachment")
                 mail.add_attachment(attachment)
 
-        send_time = now()
         mail_body = mail.get()
-        if hasattr(settings, "EMAIL_SENDGRID_API_DEBUG") and settings.EMAIL_SENDGRID_API_DEBUG:  # type: ignore
-            logger.info("SendGrid API payload: %s", mail_body)
         res = sg.client.mail.send.post(request_body=mail_body)
-        send_dt = (now() - send_time).total_seconds()
 
         if res.status_code == 202:
-            logger.info("EMAIL_SENT %s", {"time": send_dt, "to": recipients, "subject": subject, "status": res.status_code})
+            logger.info("EMAIL_SENT %s", {"to": recipients, "subject": subject, "status": res.status_code})
         else:
             logger.info(
                 "EMAIL_ERROR %s",
-                {"time": send_dt, "to": recipients, "subject": subject, "status": res.status_code, "body": res.body},
+                {"to": recipients, "subject": subject, "status": res.status_code, "body": res.body},
             )
 
     except Exception as err:
@@ -239,10 +233,8 @@ def send_email_smtp(  # noqa
         if html:
             mail.attach_alternative(content=html, mimetype="text/html")
 
-        send_time = now()
         mail.send(fail_silently=False)
-        send_dt = (now() - send_time).total_seconds()
-        logger.info("EMAIL_SENT %s", {"time": send_dt, "to": recipients, "subject": subject})
+        logger.info("EMAIL_SENT %s", {"to": recipients, "subject": subject})
 
     except Exception as e:
         logger.error("EMAIL_ERROR %s", {"to": recipients, "subject": subject, "exception": str(e)})
